@@ -6,7 +6,7 @@ import Data.List
 import Data.Maybe (fromMaybe)
 import DataCon (dataConRepType)
 import GHC
-import Language.Haskell.GhcMod.Doc
+import Language.Haskell.GhcMod.Doc (showUnqualifiedPage)
 import Language.Haskell.GhcMod.GHCApi
 import Language.Haskell.GhcMod.Types
 import Name
@@ -19,6 +19,7 @@ import Var
 
 -- | Getting functions, classes, etc from a module.
 --   If 'detailed' is 'True', their types are also obtained.
+--   If 'operators' is 'True', operators are also returned.
 browseModule :: Options
              -> ModuleString -- ^ A module name. (e.g. \"Data.List\")
              -> IO String
@@ -38,6 +39,7 @@ browseModule opt mdlName = convert opt . format <$> withGHCDummyFile (browse opt
 
 -- | Getting functions, classes, etc from a module.
 --   If 'detailed' is 'True', their types are also obtained.
+--   If 'operators' is 'True', operators are also returned.
 browse :: Options
        -> ModuleString -- ^ A module name. (e.g. \"Data.List\")
        -> Ghc [String]
