@@ -16,9 +16,14 @@ import Prelude
 --   Warnings and errors are returned.
 checkSyntax :: Options
             -> Cradle
-            -> FilePath  -- ^ A target file
+            -> [FilePath]  -- ^ The target files.
             -> IO String
-checkSyntax opt cradle file = unlines <$> withGHC file (check opt cradle file)
+checkSyntax _   _      []    = error "ghc-mod: checkSyntax: No files given"
+checkSyntax opt cradle files = unlines <$> withGHC sessionName (check opt cradle files)
+  where
+    sessionName = case files of
+      [file] -> file
+      _      -> "MultipleFiles"
 
 ----------------------------------------------------------------
 
@@ -26,16 +31,18 @@ checkSyntax opt cradle file = unlines <$> withGHC file (check opt cradle file)
 --   Warnings and errors are returned.
 check :: Options
       -> Cradle
-      -> FilePath  -- ^ A target file
+      -> [FilePath]  -- ^ The target files.
       -> Ghc [String]
-check opt cradle fileName = checkIt `gcatch` handleErrMsg
+check _   _      []        = error "ghc-mod: check: No files given"
+check opt cradle fileNames = checkIt `gcatch` handleErrMsg ls
   where
     checkIt = do
         readLog <- initializeFlagsWithCradle opt cradle options True
-        setTargetFile fileName
+        setTargetFiles fileNames
         checkSlowAndSet
         void $ load LoadAllTargets
         liftIO readLog
     options
       | expandSplice opt = "-w:"   : ghcOpts opt
       | otherwise        = "-Wall" : ghcOpts opt
+    ls = lineSeparator opt
