@@ -1,7 +1,6 @@
 module BrowseSpec where
 
 import Control.Applicative
-import Expectation
 import Language.Haskell.GhcMod
 import Test.Hspec
 
@@ -10,13 +9,13 @@ spec = do
     describe "browseModule" $ do
         it "lists up symbols in the module" $ do
             syms <- lines <$> browseModule defaultOptions "Data.Map"
-            syms `shouldContain` "differenceWithKey"
+            syms `shouldContain` ["differenceWithKey"]
 
     describe "browseModule -d" $ do
         it "lists up symbols with type info in the module" $ do
             syms <- lines <$> browseModule defaultOptions { detailed = True } "Data.Either"
-            syms `shouldContain` "either :: (a -> c) -> (b -> c) -> Either a b -> c"
+            syms `shouldContain` ["either :: (a -> c) -> (b -> c) -> Either a b -> c"]
 
         it "lists up data constructors with type info in the module" $ do
             syms <- lines <$> browseModule defaultOptions { detailed = True} "Data.Either"
-            syms `shouldContain` "Left :: a -> Either a b"
+            syms `shouldContain` ["Left :: a -> Either a b"]
