@@ -1,15 +1,16 @@
 module DebugSpec where
 
-import Expectation
 import Language.Haskell.GhcMod
 import Test.Hspec
 
+import Dir
+
 checkFast :: String -> String -> IO ()
 checkFast file ans = withDirectory_ "test/data" $ do
     (strVer,_) <- getGHCVersion
     cradle <- findCradle Nothing strVer
     res <- debugInfo defaultOptions cradle strVer file
-    lines res `shouldContain` ans
+    lines res `shouldContain` [ans]
 
 spec :: Spec
 spec = do
